package com.blog.demo.Controller;

import com.blog.demo.entity.Post;
import com.blog.demo.Service.PostService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Optional;

@RestController
@RequestMapping("/posts")
public class PostController {

    @Autowired
    private PostService postService;

    /**
     * 查询所有文章
     *
     * @return 文章列表
     */
    @GetMapping("/findAll")
    public List<Post> getAllPosts() {
        return postService.findAll();
    }

    /**
     * 添加新文章
     *
     * @param post 新文章对象
     * @return 创建成功的响应
     */
    @PostMapping("/add")
    public ResponseEntity<Void> addPost(@RequestBody Post post) {
        postService.insert(post);
        return ResponseEntity.created(null).build(); // 返回 201 Created 状态码
    }

    /**
     * 更新文章信息
     *
     * @param post 文章对象
     * @return 更新成功的响应
     */
    @PutMapping("/update")
    public ResponseEntity<Void> updatePost(@RequestBody Post post) {
        try {
            postService.update(post);
            return ResponseEntity.noContent().build(); // 返回 204 No Content 状态码
        } catch (IllegalArgumentException e) {
            return ResponseEntity.badRequest().body(null); // 返回 400 Bad Request 状态码
        }
    }

    /**
     * 根据ID删除文章
     *
     * @param id 文章ID
     * @return 删除成功的响应
     */
    @DeleteMapping("/delete/{id}")
    public ResponseEntity<Void> deletePost(@PathVariable int id) {
        postService.deleteById(id);
        return ResponseEntity.noContent().build(); // 返回 204 No Content 状态码
    }

    /**
     * 根据ID查询文章
     *
     * @param id 文章ID
     * @return 文章对象或 404 Not Found 响应
     */
    @GetMapping("/findById/{id}")
    public ResponseEntity<Post> findById(@PathVariable int id) {
        Optional<Post> post = postService.findById(id);
        return post.map(ResponseEntity::ok).orElseGet(() -> ResponseEntity.notFound().build());
    }
}

