package com.blog.demo.Controller;

import com.blog.demo.entity.User;
import com.blog.demo.Service.UserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Optional;

@RestController
@RequestMapping("/users")
public class UserController {

    @Autowired
    private UserService userService;

    /**
     * 查询所有用户
     *
     * @return 用户列表
     */
    @GetMapping("/findAll")
    public List<User> getAllUsers() {
        return userService.findAll();
    }

    /**
     * 添加新用户
     *
     * @param user 新用户对象
     * @return 创建成功的响应
     */
    @PostMapping("/add")
    public ResponseEntity<Void> addUser(@RequestBody User user) {
        userService.insert(user);
        return ResponseEntity.created(null).build(); // 返回 201 Created 状态码
    }

    /**
     * 更新用户信息
     *
     * @param user 用户对象
     * @return 更新成功的响应
     */
    @PutMapping("/update")
    public ResponseEntity<Void> updateUser(@RequestBody User user) {
        try {
            userService.update(user);
            return ResponseEntity.noContent().build(); // 返回 204 No Content 状态码
        } catch (IllegalArgumentException e) {
            return ResponseEntity.badRequest().body(null); // 返回 400 Bad Request 状态码
        }
    }

    /**
     * 根据ID删除用户
     *
     * @param id 用户ID
     * @return 删除成功的响应
     */
    @DeleteMapping("/delete/{id}")
    public ResponseEntity<Void> deleteUser(@PathVariable int id) {
        userService.deleteById(id);
        return ResponseEntity.noContent().build(); // 返回 204 No Content 状态码
    }

    /**
     * 根据ID查询用户
     *
     * @param id 用户ID
     * @return 用户对象或 404 Not Found 响应
     */
    @GetMapping("/findById/{id}")
    public ResponseEntity<User> findById(@PathVariable int id) {
        Optional<User> user = userService.findById(id);
        return user.map(ResponseEntity::ok).orElseGet(() -> ResponseEntity.notFound().build());
    }

}
