package com.blog.demo.Controller;

import com.blog.demo.Service.UserSecurityQuestionsAnswersService;
import com.blog.demo.entity.UserSecurityQuestionsAnswers;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Optional;

@RestController
@RequestMapping("/usqa")
public class UserSecurityQuestionsAnswersController {

    @Autowired
    private UserSecurityQuestionsAnswersService userSecurityQuestionsAnswersService;

    /**
     * 查询所有用户密保问题和答案
     *
     * @return 用户密保问题和答案列表
     */
    @GetMapping("/findAll")
    public List<UserSecurityQuestionsAnswers> getAllUserSecurityQuestionsAnswers() {
        return userSecurityQuestionsAnswersService.findAll();
    }

    /**
     * 根据ID查询用户密保问题和答案
     *
     * @param userID 记录ID
     * @return 用户密保问题和答案对象或 404 Not Found 响应
     */
    @GetMapping("/findAllByUserId/{userID}")
    public ResponseEntity<List<UserSecurityQuestionsAnswers>> findAllByUserId(@PathVariable int userID) {
        List<UserSecurityQuestionsAnswers> results = userSecurityQuestionsAnswersService.findAllByUserId(userID);
        return ResponseEntity.ok(results);
    }

    /**
     * 添加新用户密保问题和答案
     *
     * @param userSecurityQuestionsAnswers 新用户密保问题和答案对象
     * @return 创建成功的响应
     */
    @PostMapping("/add")
    public ResponseEntity<Void> addUserSecurityQuestionsAnswers(@RequestBody UserSecurityQuestionsAnswers userSecurityQuestionsAnswers) {
        userSecurityQuestionsAnswersService.insert(userSecurityQuestionsAnswers);
        return ResponseEntity.created(null).build(); // 返回 201 Created 状态码
    }

    /**
     * 更新用户密保问题和答案
     *
     * @param userSecurityQuestionsAnswers 用户密保问题和答案对象
     * @return 更新成功的响应
     */
    @PutMapping("/update")
    public ResponseEntity<Void> updateUserSecurityQuestionsAnswers(@RequestBody UserSecurityQuestionsAnswers userSecurityQuestionsAnswers) {
        userSecurityQuestionsAnswersService.update(userSecurityQuestionsAnswers);
        return ResponseEntity.noContent().build(); // 返回 204 No Content 状态码
    }

    /**
     * 根据ID删除用户密保问题和答案
     *
     * @param recordID 记录ID
     * @return 删除成功的响应
     */
    @DeleteMapping("/delete/{recordID}")
    public ResponseEntity<Void> deleteUserSecurityQuestionsAnswers(@PathVariable int recordID) {
        userSecurityQuestionsAnswersService.deleteById(recordID);
        return ResponseEntity.noContent().build(); // 返回 204 No Content 状态码
    }
    /**
     * 根据 userID 删除记录
     *
     * @param userID 用户ID
     * @return 删除结果
     */
    @DeleteMapping("/delete-by-user-id/{userID}")
    public ResponseEntity<String> deleteByUserID(@PathVariable int userID) {
        userSecurityQuestionsAnswersService.deleteByUserID(userID);
        return ResponseEntity.ok("Records deleted successfully");
    }
}
