package com.blog.demo.Service;

import com.blog.demo.Mapper.PostMapper;
import com.blog.demo.entity.Post;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;

@Service
public class PostService {

    @Autowired
    private PostMapper postMapper;

    /**
     * 查询所有文章
     *
     * @return 文章列表
     */
    public List<Post> findAll() {
        return postMapper.findAll();
    }

    /**
     * 插入新文章
     *
     * @param post 新文章对象
     */
    public void insert(Post post) {
        postMapper.insert(post);
    }

    /**
     * 更新文章信息
     *
     * @param post 文章对象
     */
    public void update(Post post) {
        if (post.getPostID() == 0) {
            throw new IllegalArgumentException("文章ID不能为空");
        }
        postMapper.update(post);
    }

    /**
     * 根据ID删除文章
     *
     * @param id 文章ID
     */
    public void deleteById(int id) {
        postMapper.deleteById(id);
    }

    /**
     * 根据ID查询文章
     *
     * @param id 文章ID
     * @return 可选的文章对象
     */
    public Optional<Post> findById(int id) {
        return Optional.ofNullable(postMapper.findById(id));
    }
}

