package com.blog.demo.Service;

import com.blog.demo.Mapper.UserSecurityQuestionsAnswersMapper;
import com.blog.demo.entity.UserSecurityQuestionsAnswers;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;

@Service
public class UserSecurityQuestionsAnswersService {

    @Autowired
    private UserSecurityQuestionsAnswersMapper userSecurityQuestionsAnswersMapper;

    /**
     * 查询所有用户安全问题答案
     *
     * @return 用户安全问题答案列表
     */
    public List<UserSecurityQuestionsAnswers> findAll() {
        return userSecurityQuestionsAnswersMapper.findAll();
    }

    /**
     * 插入新的用户安全问题答案
     *
     * @param userSecurityQuestionsAnswers 新的用户安全问题答案对象
     */
    public void insert(UserSecurityQuestionsAnswers userSecurityQuestionsAnswers) {
        userSecurityQuestionsAnswersMapper.insert(userSecurityQuestionsAnswers);
    }

    /**
     * 更新用户安全问题答案
     *
     * @param userSecurityQuestionsAnswers 用户安全问题答案对象
     */
    public void update(UserSecurityQuestionsAnswers userSecurityQuestionsAnswers) {
        if (userSecurityQuestionsAnswers.getRecordID() == 0) {
            throw new IllegalArgumentException("记录ID不能为空");
        }
        userSecurityQuestionsAnswersMapper.update(userSecurityQuestionsAnswers);
    }

    /**
     * 根据ID删除用户安全问题答案
     *
     * @param recordID 记录ID
     */
    public void deleteById(int recordID) {
        userSecurityQuestionsAnswersMapper.deleteById(recordID);
    }

    /**
     * 根据ID查询用户安全问题答案
     *
     * @param userID 记录ID
     * @return 可选的用户安全问题答案对象
     */
    public List<UserSecurityQuestionsAnswers> findAllByUserId(int userID) {
        return userSecurityQuestionsAnswersMapper.findAllByUserId(userID);
    }

    /**
     * 根据 userID 删除记录
     *
     * @param userID 用户ID
     */
    public void deleteByUserID(int userID) {
        userSecurityQuestionsAnswersMapper.deleteByUserID(userID);
    }
}
