package com.blog.demo.Service;

import com.blog.demo.Mapper.UserMapper;
import com.blog.demo.entity.User;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;

@Service
public class UserService {

    @Autowired
    private UserMapper userMapper;


    /**
     * 查询所有用户
     *
     * @return 用户列表
     */
    public List<User> findAll() {
        return userMapper.findAll();
    }

    /**
     * 插入新用户
     *
     * @param user 新用户对象
     */
    public void insert(User user) {
        userMapper.insert(user);
    }

    /**
     * 更新用户信息
     *
     * @param user 用户对象
     */
    public void update(User user) {
        if (user.getUserID() == 0) {
            throw new IllegalArgumentException("用户ID不能为空");
        }
        userMapper.update(user);
    }

    /**
     * 根据ID删除用户
     *
     * @param id 用户ID
     */
    public void deleteById(int id) {
        userMapper.deleteById(id);
    }

    /**
     * 根据ID查询用户
     *
     * @param id 用户ID
     * @return 可选的用户对象
     */
    public Optional<User> findById(int id) {
        return Optional.ofNullable(userMapper.findById(id));
    }

    }
